@@ -32,7 +32,7 @@ using namespace std;
 
 
 gameLobbyDialogImpl::gameLobbyDialogImpl(startWindowImpl *parent, ConfigFile *c)
-	: QDialog(parent), myW(NULL), myStartWindow(parent), myConfig(c), currentGameName(""), myPlayerId(0), isGameAdministrator(false), inGame(false), guestMode(false), blinkingButtonAnimationState(true), myChat(NULL), keyUpCounter(0), infoMsgToShowId(0), currentInvitationGameId(0), inviteDialogIsCurrentlyShown(false), autoStartTimerCounter(0)
+: QDialog(parent), myW(NULL), myStartWindow(parent), myConfig(c), currentGameName(""), myPlayerId(0), isGameAdministrator(false), inGame(false), guestMode(false), blinkingButtonAnimationState(true), myChat(NULL), keyUpCounter(0), infoMsgToShowId(0), currentInvitationGameId(0), inviteDialogIsCurrentlyShown(false), autoStartTimerCounter(0), lastNickListFilterState(0)
 {
 
 #ifdef __APPLE__
@@ -116,7 +116,11 @@ gameLobbyDialogImpl::gameLobbyDialogImpl(startWindowImpl *parent, ConfigFile *c)
 	treeView_GameList->setColumnWidth(3,40);
 	treeView_GameList->setColumnWidth(4,40);
 
+#ifdef GUI_800x480
+	treeView_GameList->setStyleSheet("QTreeView {background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat; color:rgb(0, 0, 0); font: 14px}");
+#else
 	treeView_GameList->setStyleSheet("QTreeView {background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat;}");
+#endif
 	treeView_GameList->setAutoFillBackground(TRUE);
 
 	myNickListModel = new QStandardItemModel(this);
@@ -277,7 +281,7 @@ void gameLobbyDialogImpl::createGame()
 		gameData.playerActionTimeoutSec = myCreateInternetGameDialog->spinBox_netTimeOutPlayerAction->value();
 		gameData.gameType = GameType(myCreateInternetGameDialog->comboBox_gameType->itemData(myCreateInternetGameDialog->comboBox_gameType->currentIndex(), Qt::UserRole).toInt());
 
-		currentGameName = myCreateInternetGameDialog->lineEdit_gameName->text();
+		currentGameName = myCreateInternetGameDialog->lineEdit_gameName->text().simplified();
 
 		switch (gameData.gameType) {
 		case GAME_TYPE_NORMAL: {
@@ -313,7 +317,7 @@ void gameLobbyDialogImpl::createGame()
 
 		updateDialogBlinds(gameData);
 
-		label_TimeoutForPlayerAction->setText(QString::number(gameData.playerActionTimeoutSec));
+		label_GameTiming->setText(QString::number(gameData.playerActionTimeoutSec)+tr(" sec (action)")+"\n"+QString::number(gameData.delayBetweenHandsSec)+tr(" sec (hand delay)"));
 
 		mySession->clientCreateGame(gameData, currentGameName.toUtf8().constData(), myCreateInternetGameDialog->lineEdit_Password->text().toUtf8().constData());
 
@@ -467,7 +471,7 @@ void gameLobbyDialogImpl::gameSelected(const QModelIndex &index)
 		//		label_MaximumNumberOfPlayers->setText(QString::number(info.data.maxNumberOfPlayers));s
 		updateDialogBlinds(info.data);
 
-		label_TimeoutForPlayerAction->setText(QString::number(info.data.playerActionTimeoutSec));
+		label_GameTiming->setText(QString::number(info.data.playerActionTimeoutSec)+tr(" sec (action)")+"\n"+QString::number(info.data.delayBetweenHandsSec)+tr(" sec (hand delay)"));
 
 		treeWidget_connectedPlayers->clear();
 		PlayerIdList::const_iterator i = info.players.begin();
@@ -756,7 +760,7 @@ void gameLobbyDialogImpl::clearDialog()
 	label_blindsRaiseIntervall->setText("");
 	label_blindsRaiseMode->setText("");
 	label_blindsList->setText("");
-	label_TimeoutForPlayerAction->setText("");
+	label_GameTiming->setText("");
 
 	myGameListModel->clear();
 	myGameListSelectionModel->clear();
@@ -1131,7 +1135,7 @@ void gameLobbyDialogImpl::joinedGameDialogUpdate()
 	label_SmallBlind->setText(QString("%L1").arg(info.data.firstSmallBlind));
 	label_StartCash->setText(QString("%L1").arg(info.data.startMoney));
 	updateDialogBlinds(info.data);
-	label_TimeoutForPlayerAction->setText(QString::number(info.data.playerActionTimeoutSec));
+	label_GameTiming->setText(QString::number(info.data.playerActionTimeoutSec)+tr(" sec (action)")+"\n"+QString::number(info.data.delayBetweenHandsSec)+tr(" sec (hand delay)"));
 
 	QTreeWidgetItem *header = treeWidget_connectedPlayers->headerItem();
 	header->setText(0, tr("Connected players - Max. %1").arg(info.data.maxNumberOfPlayers));
@@ -1160,7 +1164,7 @@ void gameLobbyDialogImpl::leftGameDialogUpdate()
 	label_blindsRaiseIntervall->setText("");
 	label_blindsRaiseMode->setText("");
 	label_blindsList->setText("");
-	label_TimeoutForPlayerAction->setText("");
+	label_GameTiming->setText("");
 
 	treeWidget_connectedPlayers->clear();
 	pushButton_StartGame->hide();
@@ -1480,19 +1484,33 @@ void gameLobbyDialogImpl::changeGameListFilter(int index)
 
 	writeDialogSettings(1);
 
+#ifdef GUI_800x480
+	if(index) treeView_GameList->setStyleSheet("QTreeView { border-radius: 4px; border: 2px solid blue; background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat; color:rgb(0, 0, 0); font: 14px}");
+	else treeView_GameList->setStyleSheet("QTreeView { background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat; color:rgb(0, 0, 0); font: 14px}");
+#else
 	if(index) treeView_GameList->setStyleSheet("QTreeView { border-radius: 4px; border: 2px solid blue; background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat;}");
 	else treeView_GameList->setStyleSheet("QTreeView { background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat;}");
-
+#endif
 }
 
 void gameLobbyDialogImpl::changeNickListFilter(int state)
 {
+	if(lastNickListFilterState == 0) {
+		myNickListSortFilterProxyModel->setLastFilterStateCountry(false);
+		myNickListSortFilterProxyModel->setLastFilterStateAlpha(true);
+	}
+	else if(lastNickListFilterState == 1) {
+		myNickListSortFilterProxyModel->setLastFilterStateCountry(true);
+		myNickListSortFilterProxyModel->setLastFilterStateAlpha(false);
+	}
+
 	myNickListSortFilterProxyModel->setFilterState(state);
 	myNickListModel->sort(0, Qt::DescendingOrder);
 
 	myNickListSortFilterProxyModel->setFilterRegExp(QString());
 	myNickListSortFilterProxyModel->setFilterKeyColumn(0);
 
+	lastNickListFilterState = state;
 	writeDialogSettings(2);
 }
 
