@@ -18,7 +18,11 @@
 #ifndef GAMELOBBYDIALOGIMPL_H
 #define GAMELOBBYDIALOGIMPL_H
 
+#ifdef GUI_800x480
+#include <ui_gamelobbydialog_800x480.h>
+#else
 #include <ui_gamelobbydialog.h>
+#endif
 
 #include <QtGui>
 #include <QtCore>
@@ -138,7 +142,8 @@ public slots:
 	void searchForPlayerRegExpChanged();
 	void showAutoStartTimer();
 	void updateAutoStartTimer();
-	void openPlayerStats();
+	void openPlayerStats1();
+	void openPlayerStats2();
 	QString getFullCountryString(QString);
 	void closeAllChildDialogs();
 
@@ -181,7 +186,8 @@ private:
 	QMenu *nickListPlayerInfoSubMenu;
 	QMenu *connectedPlayersListPlayerInfoSubMenu;
 	QAction *nickListPlayerInGameInfo;
-	QAction *nickListOpenPlayerStats;
+	QAction *nickListOpenPlayerStats1;
+	QAction *nickListOpenPlayerStats2;
 	int infoMsgToShowId;
 	int currentInvitationGameId;
 	bool inviteDialogIsCurrentlyShown;
@@ -192,6 +198,7 @@ private:
 
 	QLabel *autoStartTimerOverlay;
 	int autoStartTimerCounter;
+	int lastNickListFilterState;
 
 protected:
 	bool eventFilter(QObject *obj, QEvent *event);
