@@ -70,12 +70,16 @@ public slots:
 	void showLog(QString fileStringPdb, QTextBrowser *tb);
 	int exportLog(QString fileStringPdb, int modus);
 
-
 public:
 	QStringList translateCardCode(int cardCode);
 
 	void writeLogFileStream(QString string);
 
+	void setMySqliteLogFileName(std::string theValue) {
+		mySqliteLogFileName = theValue;
+	}
+	std::string getMySqliteLogFileName() { return mySqliteLogFileName; }
+
 signals:
 	void signalLogPlayerActionMsg(QString playerName, int action, int setValue);
 	void signalLogNewGameHandMsg(int gameID, int handID);
@@ -98,7 +102,7 @@ private:
 	void writeLog(std::string log_string, int modus);
 	void cleanUp(result_struct &results, sqlite3 *mySqliteLogDb);
 	int convertCardStringToInt(std::string val, std::string col);
-	std::string convertCardIntToString(int code);
+	std::string convertCardIntToString(int code, int modus);
 
 	int lastGameID;
 
@@ -112,10 +116,11 @@ private:
 	QString logFileStreamString;
 	QString myAppDataPath;
 	QTextBrowser* tb;
-
 	GameTableStyleReader *myStyle;
+	std::string mySqliteLogFileName;
 
 	friend class GuiWrapper;
+
 };
 
 #endif
